@@ -1,6 +1,7 @@
 # debian/rules/dh-sequencer -- lintian check script -*- perl -*-
 
 # Copyright © 2019 Felix Lechner
+# Copyright © 2020 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +21,9 @@
 
 package Lintian::debian::rules::dh_sequencer;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use Moo;
 use namespace::clean;
@@ -38,12 +40,13 @@ sub source {
     return
       unless $rules;
 
-    my $contents = $rules->slurp;
+    my $contents = $rules->bytes;
 
     my $plain = qr/\$\@/;
     my $curly = qr/\$\{\@\}/;
+    my $asterisk = qr/\$\*/;
     my $parentheses = qr/\$\(\@\)/;
-    my $rule_altern = qr/(?:$plain|$curly|$parentheses)/;
+    my $rule_altern = qr/(?:$plain|$curly|$asterisk|$parentheses)/;
     my $rule_target = qr/(?:$rule_altern|'$rule_altern'|"$rule_altern")/;
 
     $self->tag('no-dh-sequencer')
