@@ -1,6 +1,6 @@
 # debian/source directory content -- lintian check script -*- perl -*-
 
-# Copyright (C) 2010 by Raphaël Hertzog
+# Copyright © 2010 by Raphaël Hertzog
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 
 package Lintian::debian::source_dir;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use List::MoreUtils qw(any);
