@@ -1,6 +1,6 @@
 # debian/upstream/signing-key -- lintian check script -*- perl -*-
 
-# Copyright (C) 2018 Felix Lechner
+# Copyright © 2018 Felix Lechner
 #
 # This program is free software.  It is distributed under the terms of
 # the GNU General Public License as published by the Free Software
@@ -20,8 +20,9 @@
 
 package Lintian::debian::upstream::signing_key;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use File::Temp;
@@ -45,7 +46,7 @@ sub source {
     my %key_locations;
     for my $key_name ($SIGNING_KEY_FILENAMES->all) {
         my $path = $processable->patched->resolve_path("debian/$key_name");
-        $key_locations{$key_name} = $path->fs_path
+        $key_locations{$key_name} = $path->unpacked_path
           if $path && $path->is_file;
     }
 
