@@ -1,9 +1,10 @@
 # fields/package-relations -- lintian check script (rewrite) -*- perl -*-
 #
-# Copyright (C) 2004 Marc Brockschmidt
+# Copyright © 2004 Marc Brockschmidt
+# Copyright © 2019-2020 Chris Lamb <lamby@debian.org>
 #
 # Parts of the code were taken from the old check script, which
-# was Copyright (C) 1998 Richard Braakman (also licensed under the
+# was Copyright © 1998 Richard Braakman (also licensed under the
 # GPL 2 or higher)
 #
 # This program is free software; you can redistribute it and/or modify
@@ -24,8 +25,9 @@
 
 package Lintian::fields::package_relations;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Dpkg::Version qw(version_check);
@@ -166,8 +168,9 @@ sub installable {
                 && $known_obsolete_emacs{$alternatives[0][0]});
 
             for my $part_d (@alternatives) {
-                my ($d_pkg, undef, $d_version, undef, undef, $rest,
-                    $part_d_orig)= @$part_d;
+                my ($d_pkg, $d_march, $d_version, undef, undef, $rest,
+                    $part_d_orig)
+                  = @$part_d;
 
                 $self->tag('invalid-versioned-provides', $part_d_orig)
                   if ( $field eq 'provides'
@@ -196,6 +199,7 @@ sub installable {
 
                 $self->tag('package-relation-with-self',"$field: $part_d_orig")
                   if ($pkg eq $d_pkg)
+                  && (!$d_march)
                   && ( $field ne 'conflicts'
                     && $field ne 'replaces'
                     && $field ne 'provides');
@@ -559,13 +563,22 @@ sub source {
     }
 
     # Check for duplicates.
-    my $build_all = $processable->relation('build-depends-all');
-    my @dups = $build_all->duplicates;
-    for my $dup (@dups) {
-        $self->tag('package-has-a-duplicate-build-relation',join(', ', @$dup));
+    my @to_check = (
+        ['build-depends'],
+        ['build-depends', 'build-depends-indep'],
+        ['build-depends', 'build-depends-arch']);
+    foreach my $fields (@to_check) {
+        my $relation
+          = Lintian::Relation->and(map { $processable->relation($_) }@$fields);
+        my @dups = $relation->duplicates;
+        for my $dup (@dups) {
+            $self->tag('package-has-a-duplicate-build-relation',
+                join(', ', @$dup));
+        }
     }
 
     # Make sure build dependencies and conflicts are consistent.
+    my $build_all = $processable->relation('build-depends-all');
     for (
         $depend{'build-conflicts'},
         $depend{'build-conflicts-indep'},
