@@ -1,6 +1,6 @@
 # files/symbolic-links/broken -- lintian check script -*- perl -*-
 #
-# Copyright (C) 2011 Niels Thykier
+# Copyright © 2011 Niels Thykier
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 
 package Lintian::files::symbolic_links::broken;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use File::Basename qw(dirname);
