@@ -1,6 +1,6 @@
 # pe -- lintian check script -*- perl -*-
 
-# Copyright (C) 2017 Chris Lamb <lamby@debian.org>
+# Copyright © 2017-2019 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 
 package Lintian::pe;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use constant SPACE  =>  q{ };
@@ -44,7 +45,7 @@ sub files {
       unless $file->is_open_ok;
 
     my $buf;
-    my $fd = $file->open;
+    open(my $fd, '<', $file->unpacked_path);
 
     eval {
         # offset to main header
